diff --git a/Makefile b/Makefile
index 7e4a527..b9beaf1 100644
--- a/Makefile
+++ b/Makefile
@@ -74,12 +74,15 @@ NOISE:="-o ${TMP}/trace"
 PART:=	cprogs
 SUBPART:= everything
 RUNTYPE:=serial
-TESTSET:=catstests
+# can be richtests, catstests, regresstests (see src/input/Makefile)
+TESTSET:=alltests
+BUILD:=full
 
 
 ENV:= \
 AWK=${AWK} \
 BOOKS=${BOOKS} \
+BUILD=${BUILD} \
 BYE=${BYE} \
 CC=${CC} \
 CCF=${CCF} \
@@ -130,25 +133,32 @@ all: noweb ${MNT}/${SYS}/bin/document
 	@ ${DOCUMENT} Makefile
 	@ mkdir -p ${MNT}/${SYS}/doc/src
 	@ cp Makefile.dvi ${MNT}/${SYS}/doc/src/root.Makefile.dvi
-	@ if [ "$RUNTYPE" = "parallel" ] ; then \
+	@ if [ "${RUNTYPE}" = "parallel" ] ; then \
 	   ( echo p4 starting parallel make of input files ; \
 	     ${ENV} ${MAKE} input ${NOISE} & ) ; \
 	  else \
+           if [ "${BUILD}" = "full" ] ; then \
 	   ( echo s4 starting serial make of input files ; \
 	     mkdir -p ${MNT}/${SYS}/doc/src/input ; \
              cd ${MNT}/${SYS}/doc/src/input ; \
 	     cp ${SRC}/scripts/tex/axiom.sty . ; \
-	     for i in `ls ${SRC}/input/*.input.pamphlet` ; \
-               do latex $$i ; \
-               done ; \
-	      rm -f *~ ; \
-	      rm -f *.pamphlet~ ; \
-	      rm -f *.log ; \
-	      rm -f *.tex ; \
-	      rm -f *.toc ; \
-	      rm -f *.aux ) ; \
+	     for i in `ls ${SRC}/input/*.input.pamphlet` ; do \
+	      if [ .${NOISE} = . ] ; \
+	      then \
+               latex $$i ; \
+	      else \
+	       ( echo p4a making $$i ; \
+	         latex $$i >${TMP}/trace ) ; \
+	      fi ; \
+             done ; \
+	     rm -f *~ ; \
+	     rm -f *.pamphlet~ ; \
+	     rm -f *.log ; \
+	     rm -f *.tex ; \
+	     rm -f *.toc ; \
+	     rm -f *.aux ) ; fi ; \
 	  fi
-	@ if [ "$RUNTYPE" = "parallel" ] ; then \
+	@ if [ "${RUNTYPE}" = "parallel" ] ; then \
 	    ( echo s2 starting parallel make of books ; \
 	      echo s3 ${SPD}/books/Makefile from \
                    ${SPD}/books/Makefile.pamphlet ; \
@@ -163,9 +173,10 @@ all: noweb ${MNT}/${SYS}/bin/document
 	      cd ${SPD}/books ; \
               ${DOCUMENT} Makefile ; \
               cp Makefile.dvi ${MNT}/${SYS}/doc/src/books.Makefile.dvi ; \
-	      ${ENV} ${MAKE} ) ; \
+              if [ "${BUILD}" = "full" ] ; then \
+	      ${ENV} ${MAKE} ; fi ) ; \
 	  fi
-	@ if [ "$RUNTYPE" = "parallel" ] ; then \
+	@ if [ "${RUNTYPE}" = "parallel" ] ; then \
 	    ( echo p5 starting parallel make of xhtml documents ; \
 	      ${ENV} ${MAKE} xhtml ${NOISE} & ) ; \
 	  else \
@@ -173,7 +184,8 @@ all: noweb ${MNT}/${SYS}/bin/document
 	      mkdir -p ${MNT}/${SYS}/doc/hypertex/bitmaps ; \
 	      cd ${MNT}/${SYS}/doc/hypertex ; \
 	      ${TANGLE} -t8 ${SPD}/books/bookvol11.pamphlet >Makefile11 ; \
-	      ${ENV} ${MAKE} -j 10 -f Makefile11 ; \
+              if [ "${BUILD}" = "full" ] ; then \
+	      ${ENV} ${MAKE} -j 10 -f Makefile11 ; fi ; \
 	      rm -f Makefile11 ) ; \
 	  fi
 	@ echo p7 starting make of src
@@ -182,7 +194,8 @@ all: noweb ${MNT}/${SYS}/bin/document
 
 input:
 	@ echo p9 making input documents
-	@ ( mkdir -p ${MNT}/${SYS}/doc/src/input ; \
+	@ if [ "${BUILD}" = "full" ] ; then \
+	  ( mkdir -p ${MNT}/${SYS}/doc/src/input ; \
             cd ${MNT}/${SYS}/doc/src/input ; \
 	    cp ${SRC}/scripts/tex/axiom.sty . ; \
 	    for i in `ls ${SRC}/input/*.input.pamphlet` ; \
@@ -193,15 +206,16 @@ input:
 	     rm -f *.log ; \
 	     rm -f *.tex ; \
 	     rm -f *.toc ; \
-	     rm -f *.aux )
+	     rm -f *.aux ) ; fi
 
 xhtml:
 	@ echo p10 making xhtml pages
 	@mkdir -p ${MNT}/${SYS}/doc/hypertex/bitmaps
-	@(cd ${MNT}/${SYS}/doc/hypertex ; \
+	@ if [ "${BUILD}" = "full" ] ; then \
+	 (cd ${MNT}/${SYS}/doc/hypertex ; \
 	  ${TANGLE} -t8 ${SPD}/books/bookvol11.pamphlet >Makefile11 ; \
 	  ${ENV} ${MAKE} -j 10 -f Makefile11 ; \
-	  rm -f Makefile11 )
+	  rm -f Makefile11 ) ; fi
 
 book:
 	@ echo 79 building the book as ${MNT}/${SYS}/doc/book.dvi 
diff --git a/Makefile.pamphlet b/Makefile.pamphlet
index 8a8c4fb..61a75e7 100644
--- a/Makefile.pamphlet
+++ b/Makefile.pamphlet
@@ -46,10 +46,11 @@ all: noweb ${MNT}/${SYS}/bin/document
 	@ ${DOCUMENT} Makefile
 	@ mkdir -p ${MNT}/${SYS}/doc/src
 	@ cp Makefile.dvi ${MNT}/${SYS}/doc/src/root.Makefile.dvi
-	@ if [ "$RUNTYPE" = "parallel" ] ; then \
+	@ if [ "${RUNTYPE}" = "parallel" ] ; then \
 	   ( echo p4 starting parallel make of input files ; \
 	     ${ENV} ${MAKE} input ${NOISE} & ) ; \
 	  else \
+           if [ "${BUILD}" = "full" ] ; then \
 	   ( echo s4 starting serial make of input files ; \
 	     mkdir -p ${MNT}/${SYS}/doc/src/input ; \
              cd ${MNT}/${SYS}/doc/src/input ; \
@@ -68,9 +69,9 @@ all: noweb ${MNT}/${SYS}/bin/document
 	     rm -f *.log ; \
 	     rm -f *.tex ; \
 	     rm -f *.toc ; \
-	     rm -f *.aux ) ; \
+	     rm -f *.aux ) ; fi ; \
 	  fi
-	@ if [ "$RUNTYPE" = "parallel" ] ; then \
+	@ if [ "${RUNTYPE}" = "parallel" ] ; then \
 	    ( echo s2 starting parallel make of books ; \
 	      echo s3 ${SPD}/books/Makefile from \
                    ${SPD}/books/Makefile.pamphlet ; \
@@ -85,9 +86,10 @@ all: noweb ${MNT}/${SYS}/bin/document
 	      cd ${SPD}/books ; \
               ${DOCUMENT} Makefile ; \
               cp Makefile.dvi ${MNT}/${SYS}/doc/src/books.Makefile.dvi ; \
-	      ${ENV} ${MAKE} ) ; \
+              if [ "${BUILD}" = "full" ] ; then \
+	      ${ENV} ${MAKE} ; fi ) ; \
 	  fi
-	@ if [ "$RUNTYPE" = "parallel" ] ; then \
+	@ if [ "${RUNTYPE}" = "parallel" ] ; then \
 	    ( echo p5 starting parallel make of xhtml documents ; \
 	      ${ENV} ${MAKE} xhtml ${NOISE} & ) ; \
 	  else \
@@ -95,7 +97,8 @@ all: noweb ${MNT}/${SYS}/bin/document
 	      mkdir -p ${MNT}/${SYS}/doc/hypertex/bitmaps ; \
 	      cd ${MNT}/${SYS}/doc/hypertex ; \
 	      ${TANGLE} -t8 ${SPD}/books/bookvol11.pamphlet >Makefile11 ; \
-	      ${ENV} ${MAKE} -j 10 -f Makefile11 ; \
+              if [ "${BUILD}" = "full" ] ; then \
+	      ${ENV} ${MAKE} -j 10 -f Makefile11 ; fi ; \
 	      rm -f Makefile11 ) ; \
 	  fi
 	@ echo p7 starting make of src
@@ -104,7 +107,8 @@ all: noweb ${MNT}/${SYS}/bin/document
 
 input:
 	@ echo p9 making input documents
-	@ ( mkdir -p ${MNT}/${SYS}/doc/src/input ; \
+	@ if [ "${BUILD}" = "full" ] ; then \
+	  ( mkdir -p ${MNT}/${SYS}/doc/src/input ; \
             cd ${MNT}/${SYS}/doc/src/input ; \
 	    cp ${SRC}/scripts/tex/axiom.sty . ; \
 	    for i in `ls ${SRC}/input/*.input.pamphlet` ; \
@@ -115,15 +119,16 @@ input:
 	     rm -f *.log ; \
 	     rm -f *.tex ; \
 	     rm -f *.toc ; \
-	     rm -f *.aux )
+	     rm -f *.aux ) ; fi
 
 xhtml:
 	@ echo p10 making xhtml pages
 	@mkdir -p ${MNT}/${SYS}/doc/hypertex/bitmaps
-	@(cd ${MNT}/${SYS}/doc/hypertex ; \
+	@ if [ "${BUILD}" = "full" ] ; then \
+	 (cd ${MNT}/${SYS}/doc/hypertex ; \
 	  ${TANGLE} -t8 ${SPD}/books/bookvol11.pamphlet >Makefile11 ; \
 	  ${ENV} ${MAKE} -j 10 -f Makefile11 ; \
-	  rm -f Makefile11 )
+	  rm -f Makefile11 ) ; fi
 
 @
 
@@ -441,6 +446,7 @@ SUBPART:= everything
 RUNTYPE:=serial
 # can be richtests, catstests, regresstests (see src/input/Makefile)
 TESTSET:=alltests
+BUILD:=full
 
 @
 \subsection{The ENV variable}
@@ -449,6 +455,7 @@ TESTSET:=alltests
 ENV:= \
 AWK=${AWK} \
 BOOKS=${BOOKS} \
+BUILD=${BUILD} \
 BYE=${BYE} \
 CC=${CC} \
 CCF=${CCF} \
diff --git a/changelog b/changelog
index a9ae233..9f13bbf 100644
--- a/changelog
+++ b/changelog
@@ -1,3 +1,6 @@
+20110605 tpd src/axiom-website/patches.html 20110605.01.tpd.patch
+20110605 tpd Makefile add BUILD=full / BUILD=fast
+20110605 tpd Makefile.pamphlet add BUILD=full / BUILD=fast
 20110601 tpd src/axiom-website/patches.html 20110601.01.tpd.patch
 20110601 tpd src/interp/modemap.lisp treeshake compiler
 20110601 tpd src/interp/lisplib.lisp treeshake compiler
diff --git a/src/axiom-website/patches.html b/src/axiom-website/patches.html
index 86792a5..8fa3418 100644
--- a/src/axiom-website/patches.html
+++ b/src/axiom-website/patches.html
@@ -3522,5 +3522,7 @@ books/bookvol9 treeshake compiler<br/>
 books/bookvol9 treeshake compiler<br/>
 <a href="patches/20110601.01.tpd.patch">20110601.01.tpd.patch</a>
 books/bookvol9 treeshake compiler<br/>
+<a href="patches/20110605.01.tpd.patch">20110605.01.tpd.patch</a>
+Makefile.pamphlet add BUILD=full / BUILD=fast<br/>
  </body>
 </html>
